@@ -94,7 +94,7 @@ rlassologitEffects.default <- function(x, y, index = c(1:ncol(x)), I3 = NULL, po
     Xt <- x[, -index[i], drop = FALSE]
     I3m <- I3[-index[i]]
     lasso.regs[[i]] <- try(col <- rlassologitEffect(Xt, y, d, I3 = I3m, post = post))
-    if (class(lasso.regs[[i]]) == "try-error") {
+    if (is(lasso.regs[[i]], "try-error")) {
       next
     } else {
       coefficients[i] <- col$alpha
@@ -305,7 +305,7 @@ confint.rlassologitEffects <- function(object, parm, level = 0.95, joint = FALSE
     a <- (1 - level)/2
     a <- c(a, 1 - a)
     fac <- qt(a, n - k)
-    pct <- format.perc(a, 3)
+    pct <- format_perc(a, 3)
     ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, 
                                                                pct))
     ses <- object$se[parm]
@@ -345,7 +345,7 @@ confint.rlassologitEffects <- function(object, parm, level = 0.95, joint = FALSE
     }
      a <- (1 - level)  #not dividing by 2!
      ab <- c(a/2, 1 - a/2)
-     pct <- format.perc(ab, 3)
+     pct <- format_perc(ab, 3)
      ci <- array(NA, dim = c(length(parm), 2L), dimnames = list(parm, 
                                                                 pct))
     # hatc <- quantile(sim, probs = 1 - a)
